#
# spec file for package a2ps
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           a2ps
Version:        4.15.6
Release:        1.4
Summary:        Tool to convert ASCII/Latin Text into PostScript
License:        GPL-3.0-or-later
URL:            https://www.gnu.org/software/a2ps/a2ps.html
Source0:        https://ftp.gnu.org/gnu/a2ps/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/a2ps/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Source3:        a2ps-ko.po
Source4:        a2ps-open
Source5:        a2ps-4.14-manuals.diff
Patch0:         a2ps-4.14.diff
Patch2:         a2ps-4.14-ogonkify.patch
Patch3:         a2ps-4.14-tempfile.patch
Patch6:         a2ps-4.13-include.patch
Patch8:         a2ps-4.13-base.patch
Patch9:         a2ps-4.13-utf8.patch
Patch10:        a2ps-4.13-types.patch
Patch13:        a2ps-4.14-linker.patch
Patch17:        a2ps-buildcompare.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  emacs-nox
BuildRequires:  flex
BuildRequires:  ghostscript-fonts-std
BuildRequires:  glibc-locale
BuildRequires:  gv
BuildRequires:  libpaper-devel
BuildRequires:  libtool
BuildRequires:  psutils
BuildRequires:  texlive-latex
BuildRequires:  timezone
BuildRequires:  pkgconfig(bdw-gc)
Requires:       file
Requires:       ghostscript-fonts-std
Requires:       glibc
Requires:       glibc-locale
Requires:       sed
Requires:       w3m
Requires:       wdiff
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}
Suggests:       ImageMagick
Suggests:       acroread
Suggests:       gv
Suggests:       psutils
Suggests:       texinfo
Suggests:       texlive-latex
Provides:       a2ps-bin
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gperf
BuildRequires:  groff
BuildRequires:  makeinfo
BuildRequires:  texi2html
BuildRequires:  texinfo

%description
a2ps converts ASCII text into PostScript. This feature is used by
apsfilter, for example, to pretty-print ASCII text.

Warning: a2ps is not able to convert complex Unicode (UTF-8) text to
PostScript.  Only language text which can be converted from UTF-8 to
Latin encodings are supported.

%package -n liba2ps1
Summary:        Library to convert ASCII/Latin text into PostScript

%description -n liba2ps1
The library liba2ps used by the program a2ps to convert ASCII text into PostScript.

%package     -n a2ps-devel
Summary:        Library and header file for the interface of a2ps
Requires:       glibc-devel
Requires:       liba2ps1 = %{version}

%description -n a2ps-devel
a2ps converts ASCII text into PostScript. This feature is used by
apsfilter, for example, to pretty-print ASCII text.

Warning: a2ps is not able to convert complex Unicode (UTF-8) text to
PostScript.  Only language text which can be converted from UTF-8 to
Latin encodings are supported.

%lang_package

%prep
%setup -q -n a2ps-%{version}
touch -r configure.ac .ref
%patch -P 2  -p1
%patch -P 3  -p1
%patch -P 6  -p1 -b .incld
%patch -P 8   -b .base
%patch -P 9   -b .utf8
%patch -P 10  -b .types
%patch -P 13 -p1 -b .p13
%patch -P 17 -p1 -b .p17
%patch -P 0   -b .p0
cp -f %{SOURCE3} po/ko.po
find -type f | grep -vE '(parseppd|parsessh).y' | xargs \
sed -ri 's/59 Temple Place(,| -) Suite 330/51 Franklin Street, Fifth Floor/;s/02111-1307/02110-1301/'
find -name Makefile.in | xargs touch

%build
 autoreconf -fiv -I $PWD -I $PWD/m4
 export PATH=$PWD:$PATH
 export CFLAGS="%{optflags} -D_GNU_SOURCE $(getconf LFS_CFLAGS) -funroll-loops -Wall -pipe -fstack-protector -fPIE"
 export LPR=lpr
 export CC=gcc
 export TZ=UTC
 export COM_psselect=yes
%configure --enable-shared --disable-static --with-medium=LC_PAPER \
	--with-encoding=LC_CTYPE

 for mf in $(find -name Makefile); do
   sed -ri -e '/^am--refresh: Makefile/,/\t@:/d' \
           -e '/^\$\(top_builddir\)\/config.status:/,/^\t/d' \
           -e '/^\$\(top_srcdir\)\/configure/,/^\t/d' \
           -e '/^\$\(ACLOCAL_M4\):/,/^\t/d' \
           -e '/^\t\s+\$\(SHELL\)\s\.\/config\.status;;\s\\/{s/\.\/config.status/-c true/}' $mf
 done

 make -C contrib/ LDFLAGS="-pie" AUTOMAKE=/bin/true
 # the build system is awful so we need to build with -B and avoid parallelism
 make PSFONT_PATH=%{_datadir}/ghostscript/fonts LDFLAGS="-pie" AUTOMAKE=/bin/true AUTOHEADER=/bin/true MAKEINFO='makeinfo --force' GPERF=/usr/bin/gperf -B all
 pushd doc
   texi2html a2ps.texi
 popd
 pushd contrib/emacs
   echo "(setq load-path (cons nil load-path))" > script
   for el in a2ps.el a2ps-print.el
   do
     emacs -batch -q -l script -f batch-byte-compile $el
   done
 popd
 pushd liba2ps
   gcc -shared .libs/*.o -Wl,-soname -Wl,liba2ps.so.1 -o .libs/liba2ps.so.1.0.0
   ln -s liba2ps.so.1.0.0 .libs/liba2ps.so.1
   ln -s liba2ps.so.1.0.0 .libs/liba2ps.so
   rm -vf liba2ps.a
   sed -ri -e "/dlname/{ s/(dlname=')(')/\1liba2ps.so.1\2/ }" \
           -e "/old_library=/{ s/liba2ps\.a/liba2ps.so/ }" \
           -e "/library_names/{ s/(library_names=')(')/\1liba2ps.so.1.0.0 liba2ps.so.1 liba2ps.so\2/ }" liba2ps.la
 popd
 pushd src
   rm a2ps
   make AUTOMAKE=/bin/true AUTOHEADER=/bin/true a2ps
 popd
 # Run a test with UTF-8 Umlauts
 mkdir -p .root/.a2ps
 echo "This is a test text äöüßœéïçèãøæđ" > test.utf8
 ln -sf $PWD/ps/*		.root/.a2ps/
 ln -sf $PWD/afm/*		.root/.a2ps/
 ln -sf $PWD/encoding/*		.root/.a2ps/
 ln -sf $PWD/ogonkify/*		.root/.a2ps/
 ln -sf $PWD/ppd/*		.root/.a2ps/
 ln -sf $PWD/sheets/*		.root/.a2ps/
 A2PS_CONFIG=$PWD%{_sysconfdir}/a2ps.cfg \
        HOME=$PWD/.root LD_LIBRARY_PATH=$PWD/liba2ps/.libs \
    LC_CTYPE=en_US.UTF-8 ./src/a2ps --output=test.latin test.utf8
 grep '(This is a test text' test.latin | iconv -f latin1 -t utf8
 chmod u+rw,g+r,o+r man/*.1
 cp -p man/a2ps.1 man/a2ps.1.backup
 patch --reject-format=unified --quoting-style=literal -f -p0 -F0 < %{S:5} || :
 if test -e man/a2ps.1.rej ; then
    cat man/a2ps.1.rej
    exit 1
 else
    sed -ri '/^\.B lt-a2ps/{s/lt-(a2ps)/\1/}' man/a2ps.1 || :
 fi

%install
 make -C contrib/ install DESTDIR=%{buildroot}
 %make_install PSFONT_PATH=%{_datadir}/ghostscript/fonts
 rm -r %{buildroot}/%{_infodir}/regex*
 rm -f %{buildroot}%{_libdir}/liba2ps.la
 install -m 0755 %{SOURCE4} %{buildroot}/%{_bindir}/
 pushd contrib/emacs
   for el in a2ps.el a2ps-print.el
   do
     install ${el}c %{buildroot}%{_datadir}/emacs/site-lisp/
   done
 popd
 pushd liba2ps
   mkdir -p %{buildroot}%{_libdir}
   mkdir -p %{buildroot}%{_includedir}
   install .libs/liba2ps.so.1.0.0 %{buildroot}%{_libdir}/
   ln -s liba2ps.so.1.0.0 %{buildroot}%{_libdir}/liba2ps.so.1
   ln -s liba2ps.so.1.0.0 %{buildroot}%{_libdir}/liba2ps.so
   install -m 0644 liba2ps.h %{buildroot}%{_includedir}
 popd
 for sc in card fixps lp2 pdiff
 do
   sed -ri '1 {s@/env +@/@}' %{buildroot}%{_bindir}/$sc
 done
%find_lang %{name} %{name}.lang
%find_lang %{name}-gnulib %{name}.lang

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/ogonkify.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/ogonkify.info.gz

%post   -n liba2ps1 -p /sbin/ldconfig
%postun -n liba2ps1 -p /sbin/ldconfig

%files
%doc AUTHORS ABOUT-NLS ChangeLog NEWS THANKS README doc/a2ps.html
%config %{_sysconfdir}/a2ps-site.cfg
%config %{_sysconfdir}/a2ps.cfg
%{_bindir}/a2ps
%{_bindir}/a2ps-open
%{_bindir}/a2ps-lpr-wrapper
%{_bindir}/card
%{_bindir}/composeglyphs
#{_bindir}/fixnt
%{_bindir}/fixps
%{_bindir}/ogonkify
%{_bindir}/pdiff
#{_bindir}/psmandup
%{_bindir}/lp2
#{_bindir}/psset
#{_bindir}/texi2dvi4a2ps
%{_infodir}/*.gz
%{_mandir}/man1/*.1.gz
%{_datadir}/a2ps
%{_datadir}/emacs/site-lisp/*.el
%{_datadir}/emacs/site-lisp/*.elc
%{_datadir}/ogonkify

%files lang -f %{name}.lang

%files -n liba2ps1
%{_libdir}/liba2ps.so.*

%files -n a2ps-devel
%{_includedir}/liba2ps.h
%{_libdir}/liba2ps.so

%changelog
* Tue May 21 2024 Dr. Werner Fink <werner@suse.de>
- Updated to 4.15.6 (boo#1224770)
  * Noteworthy changes in release 4.15.6 (2024-03-13) [stable]
  * Bug fixes:
  - Fix a2ps-lpr-wrapper to work with no arguments, as a2ps requires.
  - Minor fixes & improvements to sheets.map for image types and PDF.
  * Build system:
  - Minor fixes and improvements.
- Port patches
  * a2ps-4.14.diff
  * a2ps-buildcompare.patch
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Sep 18 2023 jun wang <junguo.wang@suse.com>
- Updated to 4.15.5
  * Noteworthy changes in release 4.15.5 (2023-06-22) [stable]
  * Bug fixes:
  - Fix psnup delegation. It was incorrectly changed in 4.14.90.
  - Fix to read configured paper size correctly with libpaper 1.x.
  - Fix fixps to use GhostScript’s ps2write device instead of defunct
    pswrite.
  - Fix old crash when using --stdin="".
  - Use “grep -F” rather than obsolete fgrep.
  - Fix broken a2ps-lpr-wrapper script, and translate to sh for
    portability.
  * Build:
  - Fix a problem building PDF version of manual.
  - Make configure stop if libpaper is not found.
  - Enable building the manual for gnu.org.
  * Build system:
  - Fix tests when building with libpaper 1.x.
  - Require gperf for bootstrapping, and use it correctly in build system.
  - Require a new-enough version of texinfo.
  * Documentation:
  - Various minor documentation improvements.
  - Minor tweaks.
* Fri Mar 17 2023 Dr. Werner Fink <werner@suse.de>
- Updated to 4.15
  * Noteworthy changes in release 4.15 (2023-03-07) [stable]
  * Features:
  - Replace the 'psmandup' utility with simpler 'lp2' to directly print
    documents to a simplex printer.
  - Remove the outdated 'psset' and 'fixnt', and simplify 'fixps' to
    always process its input with Ghostscript.
  - Use libpaper's paper sizes. This includes user-defined paper sizes
    when using libpaper 2. It is still possible to define custom margins
    using "Medium:" specifications in the configuration file, and the
    one size defined by a2ps that libpaper does not know about, Quarto, is
    retained for backwards compatiblity, and as an example.
  * Documentation
  - Remove some obsolete explanations.
  - Reformat --help output consistently to 80 columns.
  - Some English fixes.
  * Bug fixes:
  - Avoid a crash when a medium is not specified; instead, use the default
    libpaper size (configured by the user or sysadmin, or the locale
    default).
  - Fix some other potential crashes and compiler warnings.
  - Fixes for security bugs CVE-2001-1593, CVE-2015-8107 and CVE-2014-0466.
  - Minor bugs fixed.
  * Predefined delegations:
  - Remove support for defunct Netscape and proprietary Acrobat Reader.
  - Add lpr wrapper for automatic detection of different printing systems,
    including CUPS support.
  * Encodings:
  - Use libre fonts for KOI-8.
  - Composite fonts support.
  * Build
  - Update build system to more recent autotools and gettext versions.
  - Build man pages in a simpler and more robust way.
  - Document runtime dependencies.
  - Minor code quality improvements.
  - Minor tidy up and removal of obsolete code.
  - Require libpaper.
  - Remove OS/2 support.
  * Build
  - Build man pages in a simpler and more robust way, using x-to-1 from
    gnulib.
  - Don't install useless liba2ps.h.
  - Other minor build system improvements, including updating to more recent
    autoconf and gettext.
  - Don't require help2man or gperf to build from source.
  - Document runtime dependencies.
  - Minor code quality improvements.
  * Build:
  - Re-add a2ps to the Translation Project, and remove po files from git.
  * Bug fixes:
  - Remove reference to @COM_distill@ variable in a2ps_cfg.in.
  * Documentation:
  - Format --help output consistently to 80 columns.
  - Fix a couple of message typos.
  * Features:
  - Replace the 'psmandup' utility with simpler 'lp2' to directly print
    documents to a simplex printer.
  - Remove the outdated 'psset' and 'fixnt', and simplify 'fixps' to
    always process its input with Ghostscript.
  * Documentation
  - Remove some obsolete explanations.
  * Build
  - Minor tidy up and removal of obsolete code.
  * Features:
  - Use libpaper's paper sizes. This includes user-defined paper sizes
    when using libpaper 2. It is still possible to define custom margins
    using "Medium:" specifications in the configuration file, and the
    one size defined by a2ps that libpaper does not know about, Quarto, is
    retained for backwards compatiblity, and as an example.
  * Bug fixes:
  - Avoid a crash when a medium is not specified; instead, use the default
    libpaper size (configured by the user or sysadmin, or the locale
    default).
  - Fix some other potential crashes and compiler warnings.
  * Documentation:
  - Reformat --help output consistently to 80 columns.
  * Build:
  - Require autoconf 2.71.
  - Require libpaper.
  * Documentation:
  - Undo reformatting of --help output from 4.14.91, so as not to annoy
    translators (thanks, Benno Schulenberg!).
  - Use gnulib function to emit bug reporting information.  This also
    fixes a problem with the translated strings introduced in 4.14.91
    (thanks, Benno Schulenberg!).
  * Build:
  - Re-add a2ps to the Translation Project, and remove po files from git.
  * Bug fixes:
  - Remove reference to @COM_distill@ variable in a2ps_cfg.in.
  * Documentation:
  - Format --help output consistently to 80 columns.
  - Fix a couple of message typos.
  * This is an alpha release, owing to the considerable changes since the
  last version.
  * New maintainer, Reuben Thomas.
  * Build:
  - Updated and fixed the build system, using gnulib and modern Autotools.
  - Remove OS/2 support.
  - Require libpaper.
  * Predefined delegations:
  - Remove support for defunct Netscape and proprietary Acrobat Reader.
  - Add lpr wrapper for automatic detection of different printing systems,
    including CUPS support.
  * Encodings:
  - Use libre fonts for KOI-8.
  - Composite fonts support.
  * Documentation:
  - Some English fixes.
  - Man page for fixnt.
  * Bug fixes:
  - Fixes for security bugs CVE-2001-1593, CVE-2015-8107 and CVE-2014-0466.
  - Minor bugs fixed.
- Reintroduce shared library
- Avoid configure (endless) loop during make
- New a2ps-lang package
- Remove obsolete patches
  * CVE-2014-0466.diff
  * a2ps-4.13-psgen.patch
  * a2ps-4.13-security.patch
  * a2ps-4.14-acroread.patch
  * a2ps-4.14-automake.patch
  * a2ps-4.14-bnc955194.patch
  * a2ps-4.14-gperf.patch
  * a2ps-4.14-iswprint.patch
  * a2ps-4.14-texinfo-6.7.patch
  * reproducible.patch
- Port patches
  * a2ps-4.13-base.patch
  * a2ps-4.13-include.patch
  * a2ps-4.13-types.patch
  * a2ps-4.13-utf8.patch
  * a2ps-4.14-linker.patch
  * a2ps-4.14-manuals.diff
  * a2ps-4.14-ogonkify.patch
  * a2ps-4.14-tempfile.patch
  * a2ps-4.14.diff
  * a2ps-buildcompare.patch
* Mon Feb  7 2022 Dr. Werner Fink <werner@suse.de>
- For iconv glibc-locale should be installed
* Wed May 13 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Discard rm of nonexistent %%{_infodir}/dir to fix build
* Thu Nov  7 2019 Dr. Werner Fink <werner@suse.de>
- Add patch a2ps-4.14-texinfo-6.7.patch to let it build with
  texinfo-6.7 as well
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Implement shared library packaging policy.
- Remove --with-pic which is useless with --disable-static.
- Use noun phrase in summary.
- Resolve PreReq FIXMEs.
* Tue Oct 16 2018 werner@suse.de
- Make LFS support work on 32bit architectures (bsc#1112014)
* Mon Jul 16 2018 bwiedemann@suse.com
- Add reproducible.patch to fix build date (boo#1047218)
- Run build non-parallelized and with make -B because of
  poorly specified make build dependencies to make build reproducible
* Thu Jun 29 2017 werner@suse.de
- Be more flexible in patching man/a2ps.1
* Mon May 29 2017 werner@suse.de
- Split off patch a2ps-4.14-manuals.diff as otherwise we might
  not patch the final manual page
- Avoid broken macro in manual page templates
* Thu Mar  3 2016 olaf@aepfle.de
- Reduce build-compare noise, no timestamps
  a2ps-buildcompare.patch
* Mon Nov 16 2015 werner@suse.de
- Add patch a2ps-4.14-bnc955194.patch to fix format string
  vulnerability (bnc#955194)
* Sun May 24 2015 mpluskal@suse.com
- Add gpg signature
- Update info scriplet dependencies
- Add a2ps-4.14-gperf.patch (boo#932138)
- Cleanup spec file with spec-cleaner
* Wed Mar  4 2015 werner@suse.de
- Add a test case to be able to detect any broken backport
* Tue Mar  3 2015 werner@suse.de
- Avoid zero length FAQ
* Tue Mar  3 2015 werner@suse.de
- Avoid automake-1.9 as there is no automake-1.9 anymore
  therefore add patch a2ps-4.14-automake.patch
- Avoid useless warning and add patch a2ps-4.14-iswprint.patch
* Mon Mar  2 2015 werner@suse.de
- Fix ported patch a2ps-4.14.diff to avoid bug in locale handling
  as well in font format definition (boo#919249, boo#919243)
* Fri Feb  6 2015 werner@suse.de
- BuildRequire texi2html
* Mon Feb  2 2015 werner@suse.de
- Correct patch a2ps-4.14.diff (boo#915483)
- Make a2ps-open smart now
* Tue Dec 23 2014 meissner@suse.com
- build with PIE
* Mon Nov 10 2014 sfalken@opensuse.org
- Removed pkgconfig entries from Requires: section, per OBS
  request 243897
* Thu Oct  2 2014 crrodriguez@opensuse.org
- Do not buildrequire xorg-x11-devel, never used.
* Wed Sep 17 2014 sfalken@opensuse.org
- Fixed license in .spec file to reflect upstream changing to GPLv3
  (sr#248177)
* Wed Aug 20 2014 sfalken@opensuse.org
- Updated to 4.14
  * No UTF-8 Support yet, Basically a maintenance release.
  * GNU a2ps is now licensed under GPLv3 or later
  * Can now be built with Modern GNU Autotools, and gcc>=3.4
  * Numerous minor bugfixes, including:
  * input buffer overflow
  * IA64, PPC, and AMD64 fixes
  * Several security issues (CVE-2004-1377)
  * Addition of a number of new stylesheets
  * Translations for Japanese, Dutch, and French added/updated
- Patches rebased for 4.14 sources
  * Added:
    a2ps-4.14-acroread.patch
    a2ps-4.14-linker.patch
    a2ps-4.14-ogonkify.patch
    a2ps-4.14-tempfile.patch
    a2ps-4.14.diff
  * Deleted:
    a2ps-4.13-acroread.patch
    a2ps-4.13-linker.patch
    a2ps-4.13-ogonkify.patch
    a2ps-4.13-tempfile.patch
    a2ps-4.13.dif
    a2ps-4.13-gv-arguments.patch
    a2ps-4.13-nb.patch
    a2ps-4.13-space.patch
  * Modified:
    CVE-2014-0466.diff
- Deleted a2ps-4.13.tar.gz, replaced with a2ps-4.14.tar.gz
- a2ps.spec cleanup, and updating to work with new sources.
* Wed Jun 25 2014 werner@suse.de
- Remove obsolete tarball
* Mon Mar 31 2014 werner@suse.de
- Add patch CVE-2014-0466.diff to fix bnc#871097 - CVE-2014-0466:
  fixps does not use -dSAFER
* Mon Dec  9 2013 werner@suse.de
- Work around new linker behaviour that is enforce the liba2ps to
  depend on libm
* Mon Mar 18 2013 mmeister@suse.com
- Added download link to Source section in spec
* Mon Jul 30 2012 coolo@suse.com
- add texinfo and makeinfo as buildrequires to fix build
* Sat Jun 16 2012 jengelh@inai.de
- Use a more future-proof source path for copying in config.*
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
* Tue Feb 21 2012 werner@suse.de
- Fix shared library build on all 64bit architectures (hint from
  Dinar Valeev)
* Tue Feb  7 2012 meissner@suse.de
- copy config.* files instead of old suse_update_config macro.
* Thu Nov  3 2011 werner@suse.de
- Fix wrong parameter usage for gv in a2ps.conf (bnc#725806)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Jan 18 2011 werner@novell.com
- Remove tests/gps-ref/Converter.ps and tests/ps-ref/Converter.ps
  since they are non-free (bnc#665104)
* Tue Aug 17 2010 werner@suse.de
- Suggest a few useful packages (bnc#631293)
- Add a2ps-open as wrapper for printer `display'
* Fri Aug 28 2009 werner@suse.de
- Use return value from fopen (bnc#533398)
* Fri Jan 16 2009 crrodriguez@suse.de
- use --enable-shared and disable static libraries
* Mon Oct 27 2008 werner@suse.de
- Make liba2ps.h includable without any further includes also split
  off a devel package as suggested by Thorsten (bnc#438889)
* Tue Jul 15 2008 werner@suse.de
- Better workaround for UTF-8 files
* Tue Mar  4 2008 werner@suse.de
- Work around reencoded fonts from ogonkify in wdiff screen mode
* Fri Apr 20 2007 aj@suse.de
- Use texlive for building.
* Fri Mar 30 2007 ssommer@suse.de
- add flex to BuildRequires
* Mon Feb 19 2007 werner@suse.de
- Removed the test file Convert.java and its resulting ps files
  from source tar ball due license problems.
* Thu Feb  8 2007 ro@suse.de
- added defattr
* Fri May 19 2006 werner@suse.de
- Fix reencode_font macro in base.ps (bug #176360)
* Thu Apr 27 2006 cthiel@suse.de
- removed acroread from BuildRequires
- added patch to fake acoread on ix86 and x86_64
* Thu Feb 23 2006 werner@suse.de
- Use w3m to get ascii from html and the use a2ps its self to
  get PostScript out of ASCII. (bug #152470)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Thu Jan 12 2006 werner@suse.de
- Use the gcc stack protector
* Fri Dec  2 2005 werner@suse.de
- Fix handling of long options without arguments in a2ps script
* Tue Sep 20 2005 yxu@suse.de
- Add prototypes for functions
* Fri Jun 17 2005 werner@suse.de
- The pdiff requires wdiff (bug #91335)
* Fri May 13 2005 werner@suse.de
- Allow spaces in file names
* Fri May 13 2005 werner@suse.de
- Add a wrapper script for converting UTF-8 text _partly_ into the
  natural latin encoding of the given language enviroment (#43348)
* Sat Apr  2 2005 coolo@suse.de
- remove conflicting prototype
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Wed Aug 25 2004 werner@suse.de
- Escapes file names so that the shell groks it in single quotes
* Thu Mar 18 2004 werner@suse.de
- More temporary file security issues (bug #36368)
* Wed Aug  6 2003 werner@suse.de
- Partly workaround for ASCII and UTF-8 (mapp them to ISO 8859-15,
  bug #28348)
* Mon Jul 28 2003 werner@suse.de
- Fix keyword Lette(r)  (bug #27411)
* Wed Jun 11 2003 kukuk@suse.de
- Use %%find_lang macro
- Fix filelist
- Fix neededforbuild for emacs
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Feb 11 2003 kukuk@suse.de
- Add install-info macros [Bug #23390]
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Sun Jul 28 2002 kukuk@suse.de
- remove bzip from neededforbuild
* Thu Jul  4 2002 werner@suse.de
- Add README's and a2ps.html to package doc dir (bug # 16229)
* Thu May 23 2002 ro@suse.de
- use libdir
* Mon Feb 25 2002 pblahos@suse.cz
- filtering mozilla output in iso-8859-2 removed, mozilla does it
  correctly now, only stripping Title.
* Wed Jan 23 2002 okir@suse.de
- Fixed tempfile problem in fixnt
* Fri Dec  7 2001 werner@suse.de
- Enable automagic LC_PAPER and LC_CTYPE detection within
  a2ps-site.cfg
* Fri Aug 31 2001 pblahos@suse.cz
- implemented filtering of mozilla output in iso-8859-2
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_lib> to <ghostscript-library>
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Thu Apr 26 2001 werner@suse.de
- We've to use dots within floats (#7284)
- Fix manual page (#7192)
* Tue Apr 24 2001 werner@suse.de
- Add Euro symbol to afm of ogonkify fonts
- Implement code to be able to use LC_PAPER and LC_CTYPE for
  paper size and default encoding.
* Thu Apr 19 2001 werner@suse.de
- Use newest ogonkify to get eurifyFont working
- Include dummy metric for Euro sign to get it work with
  ghostscript and real PostScript printers (ogonkify -e L9 -E)
* Wed Mar 14 2001 ro@suse.de
- use emacs-x11 for now
* Tue Mar 13 2001 ro@suse.de
- added emacs-nox to neededforbuild
* Fri Jan 26 2001 violiet@suse.de
- remove Korean filter file = a2ps-h
* Tue Jan 23 2001 violiet@suse.de
- added Korean filter file = a2ps-h
- improvement Korean message file.
* Mon Jan 15 2001 werner@suse.de
- Fix the temporary file patch.
* Wed Jan 10 2001 werner@suse.de
- Add temporary file patch
* Fri Nov 17 2000 werner@suse.de
- Update to version 4.13(b)
- Include some package to use automatic configuration for
- Set PSFONT_PATH to /usr/share/ghostscript/fonts
* Fri Nov 17 2000 ro@suse.de
- ge_exec -> emacs
* Thu Jul  6 2000 ro@suse.de
- merged patches
* Thu Jul  6 2000 werner@suse.de
- Add `,' to atan2 in for77kwds.ssh to distinguish atan2 from cabs.
* Fri Apr  7 2000 bk@suse.de
- added suse update config macro
* Fri Feb 25 2000 kukuk@suse.de
- Fill out copyright and group tag
- Move /usr/{info,man} -> /usr/share/{info,man}
* Thu Jan 13 2000 werner@suse.de
- Fix a2ps path in a2ps.el
- Add all page names and their sizes known by ghostscript
* Thu Dec 16 1999 werner@suse.de
- Fix Bug (NULL pointer if --title="" is used)
- Remove Makefile.Linux
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul 19 1999 florian@suse.de
- update to a2ps 4.12
* Wed Oct 29 1997 florian@suse.de
- add missing patch detectet by Werner Fink
  Added the changes from Andreas Klemm for apsfilter into /usr/bin/a2ps.
  aps could use standard /usr/bin/a2ps now.
